#
# spec file for package python-QtAwesome
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-QtAwesome
Version:        1.4.0
Release:        1.1
Summary:        FontAwesome icons in PyQt and PySide applications
License:        MIT
URL:            https://github.com/spyder-ide/qtawesome
Source:         https://files.pythonhosted.org/packages/source/q/qtawesome/qtawesome-%{version}.tar.gz
BuildRequires:  %{python_module QtPy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
# SECTION test requirements
BuildRequires:  %{python_module pytest-qt}
BuildRequires:  %{python_module pytest-xvfb}
BuildRequires:  %{python_module pytest}
# Choose one of the many backend options for pytest-qt,
BuildRequires:  %{python_module PyQt6}
# /SECTION
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-QtPy
Provides:       python-qtawesome = %{version}-%{release}
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
QtAwesome enables iconic fonts such as Font Awesome and
Elusive Icons in PyQt and PySide applications.

It is a port to Python - PyQt / PySide of the QtAwesome C++
library by Rick Blommers.

%prep
%setup -q -n qtawesome-%{version}
dos2unix CHANGELOG.md README.md
#  remove entrypoint only for windows
sed -i '/qta-install-fonts-all-users/d' setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/qta-browser

%check
export PYTHONPATH="."
%pytest -v

%post
%python_install_alternative qta-browser

%postun
%python_uninstall_alternative qta-browser

%files %{python_files}
%license LICENSE.txt
%doc CHANGELOG.md README.md
%{python_sitelib}/qtawesome
%{python_sitelib}/qtawesome-%{version}.dist-info
%python_alternative %{_bindir}/qta-browser

%changelog
* Thu May 29 2025 Ben Greiner <code@bnavigator.de>
- Update to 1.4.0
  [#]# Issues Closed
  * Issue 275 - Update Codicon to 0.0.36 and fix update script (PR
    276 by @dalthviz)
  * Issue 264 - FileNotFoundError on fonts due to Windows Font
    Blocking policy (PR 273 by @dalthviz)
  * Issue 230 - Add Font Awesome 6 and remove deprecated Font
    Awesome 4 (PR 274 by @dalthviz)
  [#]# Pull Requests Merged
  * PR 277 - PR: Revert Qt binging conditional to run example.py
    and fix animations start/stop logic (CI), by @dalthviz (254)
  * PR 276 - PR: Update Codicon to 0.0.36, by @dalthviz (275)
  * PR 274 - PR: Add FontAwesome 6 icons (6.7.2) and change font
    update command, by @dalthviz (230)
  * PR 273 - PR: Return original font directory when font user
    installation load fails, by @dalthviz (264)
  * PR 272 - PR: Remove FontAwesome 4 font support, by @dalthviz
  * PR 270 - PR: Add fallback to try to load fonts from the system
    ones and add method to check info about bundled fonts, by
    @dalthviz
- Remove windows script entrypoint to install fonts systemwide
* Thu Mar 27 2025 Steve Kowalik <steven.kowalik@suse.com>
- Normalize metadata directory name.
* Fri Mar 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.3.1
  * Use GitHub raw content URL to display README images over
    package PyPI landing page by @dalthviz in #255
  * Add version to fonts assets, some error handling for Windows
    font installation logic and keep up to date update
    scripts/commands by @dalthviz in #257
  * Update Codicons update command and assets by @dalthviz in #259
- PEP517 build
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * Update Codicons (`msc`) to 0.0.35
  * Update Material Design Icons (`mdi6`) to 6.9.96
  * Improvements to the icon browser application
  * Update `readthedocs` config to version 2
  * Add API to start/stop animations to the Spin
    class
  * Provide icon size when creating an `IconWidget`
  * Remove usage of deprecated codecov package and
    move to GitHub Action variant
* Fri Dec  8 2023 Dirk Müller <dmueller@suse.com>
- update to 1.2.3:
  * Issue 227 - Import error when importing `PYSIDE6` while using
    `QtPy` <= 1.x (PR 228 by @dalthviz)
  * PR 228 - PR: Change constants used to validate `PySide`
    installation and update `PySide2` test environment to use
    `QtPy`<2.0.0, by @dalthviz (227)
  * Issue 226 - Release QtAwesome 1.2.2
  * Issue 223 - Memory leak when using spin animation class on
    PyQt bindings (PR 224 by @dalthviz)
  * Issue 213 - Add a contributing guide (PR 218 by @dalthviz)
  * In this release 3 issues were closed.
  * PR 224 - PR: Use currentThreadId to identify thread for PyQt
    bindings, by @dalthviz (223)
  * PR 218 - PR: Add contributing guide and fix macOS tests, by
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Oct 27 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.2.1
  Issues Closed
  * Issue 214 - Regression with 1.2 on Windows (PR 215 by @dalthviz)
  * Issue 212 - Release QtAwesome 1.2.1
  * Issue 210 - QtAwesome 1.2.0 incompatible with PySide2 (PR 211 by @dalthviz)
  In this release 3 issues were closed.
  Pull Requests Merged
  * PR 215 - PR: Handle per user font installation failing due to missing/not available registry keys, by @dalthviz (214)
  * PR 211 - PR: Handle PySide2 not having QtGui.QGlyphRun and add tests jobs with PySide2, by @dalthviz (210)
  In this release 2 pull requests were closed.
- Update to 1.2.0
  Full changelog https://github.com/spyder-ide/qtawesome/blob/master/CHANGELOG.md#version-120-2022-10-19
* Mon Aug 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.1.1
  * Change to "Ctrl+F" because PyQt6 doesn't support Modifier + Key by @kumattau in #183
  * Update README docs badge, Copyright year and sponsors logo by @dalthviz in #184
  * Add DeprecationWarning for FontAwesome 4.7 icon set by @dalthviz in #185
  * Try calling newer Qt methods first before falling back to deprecated/removed ones by @kumattau in #186
* Sat Oct 16 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.0.3
  * Fix: Implicit integer conversion is deprecated,
    Cast tileWidth to an integer
  * Fix: Timer should belong to parent widget
- Resolve have-choice for Qt backends tested by pytest-qt
* Tue Feb  9 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.0.2
  * Perform a font id validation
  * Add entries to the mdi charmap to be supported by Spyder
    <= 4.1.5 (1.0.1)
  * Update Material design icons to 5.4.55 (1.0.0)
  * Drop Python 2 support (1.0.0)
  * Fix deprecation warnings  due to invalid escape sequences
    (0.7.3)
- Use pytest-xvfb -- much more stable than the xvfb-run in sequence
  for each python flavor
* Tue Jul 28 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.7.2:
  * Update release instructions for the 0.x branch, by @ccordoba12
  * Do not call python directly in tests, by @scarabeusiv
  * Remove warning for Python 2.7, by @dalthviz (140)
  * al design icons to 4.9.95
  * t class to display icons as widgets
  * rowser
  * Fix file lock (125)
  * Update documentation and images (45)
  * Use Github as the only CI provider
  * Update MDI to 4.9.95
  * Add IconWidget to display icon as widget
  * Add an icon browser
  * Improve sponsors section in readme
  * Replace QtGui by QtWidgets in docs
  * Update MDI to 4.5.95
  * Update number of icons in Readme and docs
- Drop no-py2.patch, merged upstream.
- Add update-alternatives for new qta-browser binary
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to not call python2:
  * no-py2.patch
* Mon Jul 29 2019 pgajdos@suse.com
- version update to 0.6.0
  * Add rotated, hflip, and vflip options
  * Update FontAwesome and Material design icons
  * Rotate icons by static angle i.e. 90, 180 etc
  * PR: Update FontAwesome and Material design icons
  * PR: Add rotated, hflip, and vflip options
* Fri Mar  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.7:
  * Issue 113 - Corrupted icons with PyQt 5.12
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.6:
  * Too many changes to enumerate, see CHANGELOG.md
- Run tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Aug 20 2018 dmueller@suse.com
- use singlespec'ed magic requires
* Sun Aug 19 2018 stefan.bruens@rwth-aachen.de
- Fix Requires:, refer to python2 packages from python2 package
- Remove erroneously distributed __pycache__ file from sources
- Spec cleanup:
  * drop %%defattr
  * use %%license for LICENSE
* Fri Jul 21 2017 sebix+novell.com@sebix.at
- license is packaged, remove it from sources
* Thu Oct 13 2016 toddrme2178@gmail.com
- Initial version
